%define uver    1_0_hotfix_19
%define date    20240531

Name:           keeperrl
Version:        1.0.19
Release:        %mkrel 1
Summary:        Dungeon simulator game with roguelike elements
Group:          Games/Adventure
License:        GPLv2+
URL:            https://keeperrl.com
Source0:        https://github.com/miki151/keeperrl/archive/%{uver}/%{name}-%{uver}.tar.gz
Source1:        %{name}-48.png
Source2:        %{name}-128.png
Source3:        %{name}-256.png
# Avoid using steam-sdk: https://github.com/miki151/keeperrl/pull/2060
Patch1:         0001-Improve-NO_STEAMWORKS-support.patch
Patch2:         0001-Improve-NO_STEAMWORKS-support.part2.patch
# Fix build with NDEBUG defined: https://github.com/miki151/keeperrl/pull/2042
Patch3:         0001-Fix-build-with-NDEBUG-defined.patch

BuildRequires:  boost-devel
BuildRequires:  clang
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(SDL2_image)
BuildRequires:  pkgconfig(ogg)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(theora)
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(zlib)

%description
KeeperRL is an Open Source dungeon simulator game inspired by Dungeon
Keeper and Dwarf Fortress. You become an evil wizard seeking the ultimate
knowledge of destruction. You can control your minions, and explore and
conquer the world in a roguelike fashion. Combat is turn-based and very
tactical. The whole world is procedurally generated.

This is the ASCII version of KeeperRL. See https://keeperrl.com/ for
information about the version with nonfree music and graphical tiles.

%prep
%autosetup -p1 -n %{name}-%{uver}

# Replace git-based version detection
cat << EOF > gen_version.sh
echo "#define BUILD_VERSION \"%{uver} (%{_vendor})\"" > version.h
echo "#define BUILD_DATE \"%{date}\"" >> version.h
EOF

%build
%set_build_flags
export CC=clang
export CXX=clang++
%make_build \
    RELEASE=ON \
    OPT=ON \
    NO_RPATH=ON \
    NO_STEAMWORKS=ON \
    DATA_DIR=%{_gamesdatadir}/%{name} \
    ENABLE_LOCAL_USER_DIR=ON

%install
install -D -m755 keeper %{buildroot}%{_gamesbindir}/%{name}

install -d %{buildroot}%{_gamesdatadir}/%{name}
cp -a data_contrib data_free %{buildroot}%{_gamesdatadir}/%{name}/
install -m644 appconfig.txt %{buildroot}%{_gamesdatadir}/%{name}/appconfig.txt

# Menu entry
install -d %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/%{name}.desktop << EOF
[Desktop Entry]
Name=KeeperRL
GenericName=Dungeon simulator
Comment=Dungeon simulator game with roguelike elements
Exec=%{name}
Icon=%{name}
Terminal=false
Type=Application
Categories=Game;RolePlaying;
EOF

# Icon
for size in 48 128 256; do
  install -D -m644 %{_sourcedir}/%{name}-${size}.png %{buildroot}%{_iconsdir}/hicolor/${size}x${size}/apps/%{name}.png
done

%files
%{_gamesbindir}/%{name}
%{_gamesdatadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/*/apps/%{name}.png


%changelog
* Tue Nov 05 2024 daviddavid <daviddavid> 1.0.19-1.mga10
+ Revision: 2112624
- new version: 1.0.19 (thanks to Aurelian R, mga#33723)

* Mon Apr 18 2022 pterjan <pterjan> 0.0.31.2-4.mga9
+ Revision: 1851427
- Try fixing the build on arm

* Fri Apr 01 2022 umeabot <umeabot> 0.0.31.2-3.mga9
+ Revision: 1839228
- Mageia 9 Mass Rebuild

* Mon Nov 30 2020 akien <akien> 0.0.31.2-2.mga8
+ Revision: 1650772
- Rebuild for llvm 11

* Sat Oct 24 2020 akien <akien> 0.0.31.2-1.mga8
+ Revision: 1639122
- Alpha 31 hotfix 2

* Mon Oct 19 2020 akien <akien> 0.0.31-1.mga8
+ Revision: 1637134
- Alpha 31

* Sat Jun 06 2020 akien <akien> 0.0.30-1.mga8
+ Revision: 1590776
- Version alpha30

* Sun May 10 2020 akien <akien> 0.0.29-2.mga8
+ Revision: 1582653
- Add patch series from alpha 29 hotfix 1 (Oct 22, 2019)

* Sun May 10 2020 akien <akien> 0.0.29-1.mga8
+ Revision: 1582618
- Version alpha29
- Package necessary appconfig.txt file (mga#26604)

* Wed Apr 15 2020 danf <danf> 0.0.27-3.mga8
+ Revision: 1567467
- Fix Comment= in .desktop file to stop referring to debug sources

* Sat Feb 15 2020 umeabot <umeabot> 0.0.27-2.mga8
+ Revision: 1524262
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%setup_compile_flags

* Fri Mar 29 2019 akien <akien> 0.0.27-1.mga7
+ Revision: 1381059
- Alpha 27

* Sun Sep 23 2018 umeabot <umeabot> 0.0.24-2.mga7
+ Revision: 1298518
- Mageia 7 Mass Rebuild

* Wed Apr 04 2018 akien <akien> 0.0.24-1.mga7
+ Revision: 1215273
- Alpha 24

* Sat Dec 30 2017 akien <akien> 0.0.23-1.mga7
+ Revision: 1187842
- Alpha 23

* Thu Jun 15 2017 akien <akien> 0.0.22-1.mga6
+ Revision: 1107780
- Version alpha22

* Fri Mar 17 2017 akien <akien> 0.0.21-1.mga6
+ Revision: 1093263
- Version Alpha 21

* Fri Oct 28 2016 akien <akien> 0.0.20-1.mga6
+ Revision: 1063874
- Version alpha20

* Wed Jul 27 2016 akien <akien> 0.0.19-1.mga6
+ Revision: 1043794
- Version alpha 19
  o Uses SDL2 instead of SFML2

* Thu May 05 2016 akien <akien> 0.0.18-1.mga6
+ Revision: 1009597
- Alpha 18

* Sun Jan 17 2016 akien <akien> 0.0.17-3.mga6
+ Revision: 925125
- Build with -fpermissive
- Version alpha 17
- imported package keeperrl

